@@ -1,6 +1,6 @@
 package RSS::From::Forum::vBulletin;
 
-use 5.010;
+use 5.010001;
 use strict;
 use warnings;
 
@@ -14,7 +14,7 @@ use URI::URL;
 use Exporter::Lite;
 our @EXPORT_OK = qw(get_rss_from_forum);
 
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 our %SPEC;
 
@@ -26,6 +26,7 @@ sub _strip_session_param {
 }
 
 $SPEC{get_rss_from_forum} = {
+    v => 1.1,
     summary => 'Generate an RSS page by parsing vBulletin forum display page',
     description => <<'_',
 
@@ -35,23 +36,26 @@ RSS.
 
 _
     args    => {
-        url => ['str*' => {
+        url => {
             summary     => 'Forum URL (the forum display page)',
+            schema      => 'str*',
             description => <<'_',
 
 Usually it's of the form: http://host/path/forumdisplay.php?f=XXX
 
 _
-            arg_pos     => 0,
-        }],
-        ua => ['obj' => {
+            pos         => 0,
+            req         => 1,
+        },
+        ua => {
             summary     => 'Supply a custom LWP::UserAgent object',
+            schema      => 'obj*',
             description => <<'_',
 
 If supplied, will be used instead of the default LWP::UserAgent object.
 
 _
-        }],
+        },
     },
 };
 sub get_rss_from_forum {
@@ -142,16 +146,19 @@ sub get_rss_from_forum {
 1;
 #ABSTRACT: Get RSS page by parsing vBulletin forum display page
 
+__END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 RSS::From::Forum::vBulletin - Get RSS page by parsing vBulletin forum display page
 
 =head1 VERSION
 
-version 0.05
+This document describes version 0.06 of RSS::From::Forum::vBulletin (from Perl distribution RSS-From-Forum-vBulletin), released on 2014-07-22.
 
 =head1 SYNOPSIS
 
@@ -163,8 +170,6 @@ version 0.05
 
 None are exported, but they are exportable.
 
-=head1 FUNCTIONS
-
 
 =head2 get_rss_from_forum(%args) -> [status, msg, result, meta]
 
@@ -194,7 +199,32 @@ Usually it's of the form: http://host/path/forumdisplay.php?f=XXX
 
 Return value:
 
-Returns an enveloped result (an array). First element (status) is an integer containing HTTP status code (200 means OK, 4xx caller error, 5xx function error). Second element (msg) is a string containing error message, or 'OK' if status is 200. Third element (result) is optional, the actual result. Fourth element (meta) is called result metadata and is optional, a hash that contains extra information.
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+ (any)
+
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/RSS-From-Forum-vBulletin>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-RSS-From-Forum-vBulletin>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=RSS-From-Forum-vBulletin>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
 
 =head1 AUTHOR
 
@@ -202,13 +232,9 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-
-__END__
-
